@@ -272,9 +272,9 @@ def module_pattern(self, ncols=4, alpha_img=0.5, cmap='Reds'):
         f, axs = plt.subplots(math.ceil(len(modules)/ncols), ncols, figsize=(math.ceil(len(modules)/ncols)* 4, ncols * 4))
         for i in range(len(modules)):
             ax = axs.flatten()[i]
-            ax.scatter(x=self.adata.obs.x.copy(),
-                            y=self.adata.obs.y.copy(),
-                            c=np.ravel(self.adata[:, modules[i]].X.toarray()), cmap=cmap)
+            ax.scatter(x=adata.obs.x.copy(),
+                            y=adata.obs.y.copy(),
+                            c=np.ravel(adata[:, modules[i]].X.toarray()), cmap=cmap)
             ax.axis("off")
             ax.set_title(modules[i])
 
